import React, {Component} from 'react';
import {DayPilot, DayPilotScheduler} from "daypilot-pro-react";

class Scheduler extends Component {

  constructor(props) {
    super(props);

    this.schedulerRef = React.createRef();

    this.state = {
      timeHeaders: [{"groupBy": "Month"}, {"groupBy": "Day", "format": "d"}],
      scale: "Day",
      timeRangeSelectedHandling: "Enabled",
      onTimeRangeSelected: async (args) => {
        const dp = args.control;
        const modal = await DayPilot.Modal.prompt("Create a new event:", "Event 1");
        dp.clearSelection();
        if (modal.canceled) {
          return;
        }
        dp.events.add({
          start: args.start,
          end: args.end,
          id: DayPilot.guid(),
          resource: args.resource,
          text: modal.result
        });
      },
    };
  }

  get scheduler() {
    return this.schedulerRef.current.control;
  }

  componentDidMount() {

    const resources = [
      {name: "Resource A", id: "A"},
      {name: "Resource B", id: "B"},
      {name: "Resource C", id: "C"},
      {name: "Resource D", id: "D"},
      {name: "Resource E", id: "E"},
      {name: "Resource F", id: "F"},
      {name: "Resource G", id: "G"}
    ];

    const events = [
      {
        id: 1,
        text: "Event 1",
        start: "2022-06-02T00:00:00",
        end: "2022-06-05T00:00:00",
        resource: "A"
      },
      {
        id: 2,
        text: "Event 2",
        start: "2022-06-03T00:00:00",
        end: "2022-06-10T00:00:00",
        resource: "C",
        barColor: "#38761d",
        barBackColor: "#93c47d"
      },
      {
        id: 3,
        text: "Event 3",
        start: "2022-06-02T00:00:00",
        end: "2022-06-08T00:00:00",
        resource: "D",
        barColor: "#f1c232",
        barBackColor: "#f1c232"
      },
      {
        id: 4,
        text: "Event 3",
        start: "2022-06-02T00:00:00",
        end: "2022-06-08T00:00:00",
        resource: "E",
        barColor: "#cc0000",
        barBackColor: "#ea9999"
      }
    ];

    this.scheduler.update({
      events,
      resources
    });

  }

  previous() {
    const start = this.scheduler.visibleStart();
    const newStart = start.addMonths(-1);

    this.scheduler.update({
      startDate: newStart,
      days: newStart.daysInMonth()
    });
  }

  next() {

    const start = this.scheduler.visibleStart();
    const newStart = start.addMonths(1);

    this.scheduler.update({
      startDate: newStart,
      days: newStart.daysInMonth()
    });
  }

/*
  async next() {

    const start = this.scheduler.visibleStart();
    const newStart = start.addMonths(1);
    const newEnd = start.addMonths(1);

    const {data} = await axios.get(`/events?from={newStart}&to=${newEnd}`);

    this.scheduler.update({
      startDate: newStart,
      days: newStart.daysInMonth(),
      events: data
    });
  }
*/

  render() {
    return (
      <div>
        <div className={"toolbar"}>
          <button onClick={ev => this.previous()}>Previous</button>
          <button onClick={ev => this.next()}>Next</button>
        </div>
        <DayPilotScheduler
          days={30}
          startDate={"2022-06-01"}
          {...this.state}
          ref={this.schedulerRef}
        />
      </div>
    );
  }
}

export default Scheduler;
